@@ -1,6 +1,6 @@
 package Ledger::Comment;
 BEGIN {
-  $Ledger::Comment::VERSION = '0.01';
+  $Ledger::Comment::VERSION = '0.02';
 }
 
 use 5.010;
@@ -9,9 +9,8 @@ use Moo;
 
 # VERSION
 
-has line_start => (is => 'rw');
-has line_end   => (is => 'rw');
-has parent      => (is => 'rw');
+has linerefs => (is => 'rw');
+has parent   => (is => 'rw');
 
 sub BUILD {
     my ($self, $args) = @_;
@@ -19,11 +18,7 @@ sub BUILD {
 
 sub as_string {
     my ($self) = @_;
-    my $par = $self->parent;
-    my $rl = $par->can("raw_lines") ? $par->raw_lines :
-        $par->journal->raw_lines;
-
-    join "", @{$rl}[ $self->line_start .. $self->line_end ];
+    join "", map { $$_ } @{$self->linerefs};
 }
 
 1;
@@ -38,7 +33,7 @@ Ledger::Comment - Represent comment or other non-parsable lines
 
 =head1 VERSION
 
-version 0.01
+version 0.02
 
 =head1 SYNOPSIS
 
@@ -50,9 +45,7 @@ version 0.01
 
 Pointer to L<Ledger::Journal> or L<Ledger::Transaction> object.
 
-=head2 line_start => INT
-
-=head2 line_end => INT
+=head2 linerefs => [REF TO STR, ...]
 
 =head1 METHODS
 
